@@ -6,8 +6,8 @@
 // Qt
 #include <QtTest>
 // client
-#include "KWayland/Client/connection_thread.h"
 #include "KWayland/Client/compositor.h"
+#include "KWayland/Client/connection_thread.h"
 #include "KWayland/Client/event_queue.h"
 #include "KWayland/Client/pointer.h"
 #include "KWayland/Client/pointerconstraints.h"
@@ -15,8 +15,8 @@
 #include "KWayland/Client/seat.h"
 #include "KWayland/Client/surface.h"
 // server
-#include "../../src/server/display.h"
 #include "../../src/server/compositor_interface.h"
+#include "../../src/server/display.h"
 #include "../../src/server/pointerconstraints_v1_interface.h"
 #include "../../src/server/seat_interface.h"
 #include "../../src/server/surface_interface.h"
@@ -99,12 +99,14 @@ void TestPointerConstraints::init()
     registry.setup();
     QVERIFY(interfacesAnnouncedSpy.wait());
 
-    m_compositor = registry.createCompositor(registry.interface(Registry::Interface::Compositor).name, registry.interface(Registry::Interface::Compositor).version, this);
+    m_compositor =
+        registry.createCompositor(registry.interface(Registry::Interface::Compositor).name, registry.interface(Registry::Interface::Compositor).version, this);
     QVERIFY(m_compositor);
     QVERIFY(m_compositor->isValid());
 
     m_pointerConstraints = registry.createPointerConstraints(registry.interface(Registry::Interface::PointerConstraintsUnstableV1).name,
-                                                             registry.interface(Registry::Interface::PointerConstraintsUnstableV1).version, this);
+                                                             registry.interface(Registry::Interface::PointerConstraintsUnstableV1).version,
+                                                             this);
     QVERIFY(m_pointerConstraints);
     QVERIFY(m_pointerConstraints->isValid());
 
@@ -120,10 +122,10 @@ void TestPointerConstraints::init()
 
 void TestPointerConstraints::cleanup()
 {
-#define CLEANUP(variable) \
-    if (variable) { \
-        delete variable; \
-        variable = nullptr; \
+#define CLEANUP(variable)                                                                                                                                      \
+    if (variable) {                                                                                                                                            \
+        delete variable;                                                                                                                                       \
+        variable = nullptr;                                                                                                                                    \
     }
     CLEANUP(m_compositor)
     CLEANUP(m_pointerConstraints)
@@ -171,7 +173,7 @@ void TestPointerConstraints::testLockPointer()
     QVERIFY(surface->isValid());
     QVERIFY(surfaceCreatedSpy.wait());
 
-    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface*>();
+    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface *>();
     QVERIFY(serverSurface);
     QVERIFY(!serverSurface->lockedPointer());
     QVERIFY(!serverSurface->confinedPointer());
@@ -288,7 +290,7 @@ void TestPointerConstraints::testConfinePointer()
     QVERIFY(surface->isValid());
     QVERIFY(surfaceCreatedSpy.wait());
 
-    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface*>();
+    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface *>();
     QVERIFY(serverSurface);
     QVERIFY(!serverSurface->lockedPointer());
     QVERIFY(!serverSurface->confinedPointer());
