@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2020 David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2021 David Redondo <kde@david-redondo.de>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -9,16 +10,15 @@
 #include "datacontrolsource_v1_interface.h"
 #include "display.h"
 #include "seat_interface.h"
-#include "surface_interface.h"
 #include "seat_interface_p.h"
+#include "surface_interface.h"
 
 // Wayland
 #include <qwayland-server-wlr-data-control-unstable-v1.h>
 
 namespace KWaylandServer
 {
-
-class DataControlDeviceV1InterfacePrivate: public QtWaylandServer::zwlr_data_control_device_v1
+class DataControlDeviceV1InterfacePrivate : public QtWaylandServer::zwlr_data_control_device_v1
 {
 public:
     DataControlDeviceV1InterfacePrivate(DataControlDeviceV1Interface *q, SeatInterface *seat, wl_resource *resource);
@@ -28,17 +28,18 @@ public:
     DataControlDeviceV1Interface *q;
     QPointer<SeatInterface> seat;
     QPointer<DataControlSourceV1Interface> selection;
+    QPointer<DataControlSourceV1Interface> primarySelection;
 
 protected:
     void zwlr_data_control_device_v1_destroy_resource(Resource *resource) override;
     void zwlr_data_control_device_v1_set_selection(Resource *resource, wl_resource *source) override;
+    void zwlr_data_control_device_v1_set_primary_selection(Resource *resource, struct ::wl_resource *source) override;
     void zwlr_data_control_device_v1_destroy(Resource *resource) override;
 };
 
-
 DataControlDeviceV1InterfacePrivate::DataControlDeviceV1InterfacePrivate(DataControlDeviceV1Interface *_q, SeatInterface *seat, wl_resource *resource)
     : QtWaylandServer::zwlr_data_control_device_v1(resource)
-    ,  q(_q)
+    , q(_q)
     , seat(seat)
 {
 }
@@ -49,10 +50,9 @@ void DataControlDeviceV1InterfacePrivate::zwlr_data_control_device_v1_set_select
 
     if (source) {
         dataSource = DataControlSourceV1Interface::get(source);
-         Q_ASSERT(dataSource);
-         if (dataSource == seat->selection()) {
-            wl_resource_post_error(resource->handle, error::error_used_source,
-                                   "source given to set_selection was already used before");
+        Q_ASSERT(dataSource);
+        if (dataSource == seat->selection() || dataSource == seat->primarySelection()) {
+            wl_resource_post_error(resource->handle, error::error_used_source, "source given to set_selection was already used before");
             return;
         }
     }
@@ -63,6 +63,25 @@ void DataControlDeviceV1InterfacePrivate::zwlr_data_control_device_v1_set_select
     Q_EMIT q->selectionChanged(selection);
 }
 
+void DataControlDeviceV1InterfacePrivate::zwlr_data_control_device_v1_set_primary_selection(Resource *resource, wl_resource *source)
+{
+    DataControlSourceV1Interface *dataSource = nullptr;
+
+    if (source) {
+        dataSource = DataControlSourceV1Interface::get(source);
+        Q_ASSERT(dataSource);
+        if (dataSource == seat->selection() || dataSource == seat->primarySelection()) {
+            wl_resource_post_error(resource->handle, error::error_used_source, "source given to set_primary_selection was already used before");
+            return;
+        }
+    }
+    if (primarySelection) {
+        primarySelection->cancel();
+    }
+    primarySelection = dataSource;
+    Q_EMIT q->primarySelectionChanged(primarySelection);
+}
+
 void DataControlDeviceV1InterfacePrivate::zwlr_data_control_device_v1_destroy(QtWaylandServer::zwlr_data_control_device_v1::Resource *resource)
 {
     wl_resource_destroy(resource->handle);
@@ -112,6 +131,11 @@ DataControlSourceV1Interface *DataControlDeviceV1Interface::selection() const
     return d->selection;
 }
 
+DataControlSourceV1Interface *DataControlDeviceV1Interface::primarySelection() const
+{
+    return d->primarySelection;
+}
+
 void DataControlDeviceV1Interface::sendSelection(AbstractDataSource *other)
 {
     if (!other) {
@@ -130,4 +154,22 @@ void DataControlDeviceV1Interface::sendClearSelection()
     d->send_selection(nullptr);
 }
 
+void DataControlDeviceV1Interface::sendPrimarySelection(KWaylandServer::AbstractDataSource *other)
+{
+    if (!other) {
+        sendClearPrimarySelection();
+        return;
+    }
+    DataControlOfferV1Interface *offer = d->createDataOffer(other);
+    if (!offer) {
+        return;
+    }
+    d->send_primary_selection(offer->resource());
+}
+
+void DataControlDeviceV1Interface::sendClearPrimarySelection()
+{
+    d->send_primary_selection(nullptr);
+}
+
 }
