@@ -11,12 +11,13 @@
 
 #include <KWaylandServer/kwaylandserver_export.h>
 
+#include "abstract_drop_handler.h"
+
 struct wl_client;
 struct wl_resource;
 
 namespace KWaylandServer
 {
-
 class DataDeviceManagerInterface;
 class DataOfferInterface;
 class DataSourceInterface;
@@ -50,7 +51,7 @@ public:
     SurfaceInterface *surface() const;
 
 private:
-    explicit DragAndDropIcon(SurfaceInterface *surface, QObject *parent = nullptr);
+    explicit DragAndDropIcon(SurfaceInterface *surface);
     friend class DataDeviceInterfacePrivate;
     QScopedPointer<DragAndDropIconPrivate> d;
 };
@@ -66,25 +67,13 @@ private:
  * @see SeatInterface
  * @see DataSourceInterface
  */
-class KWAYLANDSERVER_EXPORT DataDeviceInterface : public QObject
+class KWAYLANDSERVER_EXPORT DataDeviceInterface : public AbstractDropHandler
 {
     Q_OBJECT
 public:
     virtual ~DataDeviceInterface();
 
     SeatInterface *seat() const;
-    DataSourceInterface *dragSource() const;
-    SurfaceInterface *origin() const;
-    /**
-     * Returns the additional icon attached to the cursor during a drag-and-drop operation.
-     * This function returns @c null if no drag-and-drop icon has been attached.
-     */
-    DragAndDropIcon *icon() const;
-
-    /**
-     * @returns the serial of the implicit grab which started the drag
-     */
-    quint32 dragImplicitGrabSerial() const;
 
     DataSourceInterface *selection() const;
 
@@ -93,7 +82,7 @@ public:
     /**
      * The event is sent when a drag-and-drop operation is ended because the implicit grab is removed.
      */
-    void drop();
+    void drop() override;
     /**
      * Updates the SurfaceInterface to which drag motion events are sent.
      *
@@ -105,18 +94,15 @@ public:
      * @param surface The SurfaceInterface which gets motion events
      * @param serial The serial to be used for enter/leave
      */
-    void updateDragTarget(SurfaceInterface *surface, quint32 serial);
-    /**
-     * Mark this DataDeviceInterface as being a proxy device for @p remote.
-     */
+    void updateDragTarget(SurfaceInterface *surface, quint32 serial) override;
     void updateProxy(SurfaceInterface *remote);
 
     wl_client *client();
 
 Q_SIGNALS:
     void aboutToBeDestroyed();
-    void dragStarted();
-    void selectionChanged(KWaylandServer::DataSourceInterface*);
+    void dragStarted(AbstractDataSource *source, SurfaceInterface *originSurface, quint32 serial, DragAndDropIcon *dragIcon);
+    void selectionChanged(KWaylandServer::DataSourceInterface *);
     void selectionCleared();
 
 private:
@@ -128,4 +114,4 @@ private:
 
 }
 
-Q_DECLARE_METATYPE(KWaylandServer::DataDeviceInterface*)
+Q_DECLARE_METATYPE(KWaylandServer::DataDeviceInterface *)
