@@ -15,7 +15,6 @@
 
 struct wl_client;
 struct wl_display;
-struct wl_event_loop;
 
 namespace KWaylandServer
 {
@@ -33,10 +32,11 @@ namespace KWaylandServer
  * @see Display
  */
 
+class ClientBuffer;
 class ClientConnection;
 class DisplayPrivate;
 class OutputInterface;
-class OutputDeviceInterface;
+class OutputDeviceV2Interface;
 class SeatInterface;
 
 /**
@@ -57,10 +57,11 @@ public:
      * returns @c true if the socket has been added successfully; otherwise returns @c false.
      *
      * The compositor can call this function even after the display has been started.
+     * @arg socketName can optionally be parsed to store the socket name represented by the given file-descriptor
      *
      * @see start()
      */
-    bool addSocketFileDescriptor(int fileDescriptor);
+    bool addSocketFileDescriptor(int fileDescriptor, const QString &socketName = QString());
     /**
      * Adds a UNIX socket with the specified @p name to the Wayland display. This function
      * returns @c true if the socket has been added successfully; otherwise returns @c false.
@@ -102,8 +103,8 @@ public:
      */
     ClientConnection *createClient(int fd);
 
-    operator wl_display*();
-    operator wl_display*() const;
+    operator wl_display *();
+    operator wl_display *() const;
     bool isRunning() const;
 
     void createShm();
@@ -111,8 +112,9 @@ public:
      * @returns All SeatInterface currently managed on the Display.
      */
     QVector<SeatInterface*> seats() const;
-    QList<OutputDeviceInterface *> outputDevices() const;
+    QList<OutputDeviceV2Interface *> outputDevices() const;
     QList<OutputInterface *> outputs() const;
+    QVector<OutputInterface *> outputsIntersecting(const QRect &rect) const;
 
     /**
      * Gets the ClientConnection for the given @p client.
@@ -121,7 +123,7 @@ public:
      * @return The ClientConnection for the given native client
      */
     ClientConnection *getConnection(wl_client *client);
-    QVector<ClientConnection*> connections() const;
+    QVector<ClientConnection *> connections() const;
 
     /**
      * Set the EGL @p display for this Wayland display.
@@ -138,14 +140,20 @@ public:
      */
     void *eglDisplay() const;
 
+    /**
+     * Returns the client buffer with the specified @a resource. Returns @c null if there's
+     * no such a buffer.
+     */
+    ClientBuffer *clientBufferForResource(wl_resource *resource) const;
+
 private Q_SLOTS:
     void flush();
 
 Q_SIGNALS:
     void socketNamesChanged();
     void runningChanged(bool);
-    void clientConnected(KWaylandServer::ClientConnection*);
-    void clientDisconnected(KWaylandServer::ClientConnection*);
+    void clientConnected(KWaylandServer::ClientConnection *);
+    void clientDisconnected(KWaylandServer::ClientConnection *);
 
 private:
     friend class DisplayPrivate;
