@@ -13,6 +13,7 @@
 #include <QSize>
 
 struct wl_resource;
+struct wl_client;
 
 namespace KWaylandServer
 {
@@ -118,6 +119,11 @@ public:
      */
     void done();
 
+    /**
+     * Submit changes to @p client.
+     */
+    void done(wl_client *client);
+
     static OutputInterface *get(wl_resource *native);
 
 Q_SIGNALS:
