@@ -10,10 +10,13 @@
 
 namespace KWaylandServer
 {
-static const quint32 s_version = 1;
+
+namespace
+{
+const quint32 s_version = 1;
 
 // helpers
-static TextInputContentHints convertContentHint(uint32_t hint)
+TextInputContentHints convertContentHint(uint32_t hint)
 {
     const auto hints = zwp_text_input_v2_content_hint(hint);
     TextInputContentHints ret = TextInputContentHint::None;
@@ -51,7 +54,7 @@ static TextInputContentHints convertContentHint(uint32_t hint)
     return ret;
 }
 
-static TextInputContentPurpose convertContentPurpose(uint32_t purpose)
+TextInputContentPurpose convertContentPurpose(uint32_t purpose)
 {
     const auto wlPurpose = QtWaylandServer::zwp_text_input_v2::content_purpose(purpose);
 
@@ -87,12 +90,6 @@ static TextInputContentPurpose convertContentPurpose(uint32_t purpose)
     }
 }
 
-TextInputManagerV2InterfacePrivate::TextInputManagerV2InterfacePrivate(TextInputManagerV2Interface *_q, Display *display)
-    : QtWaylandServer::zwp_text_input_manager_v2(*display, s_version)
-    , q(_q)
-{
-}
-
 class EnabledEmitter
 {
 public:
@@ -113,6 +110,14 @@ private:
     const bool m_wasEnabled;
 };
 
+}
+
+TextInputManagerV2InterfacePrivate::TextInputManagerV2InterfacePrivate(TextInputManagerV2Interface *_q, Display *display)
+    : QtWaylandServer::zwp_text_input_manager_v2(*display, s_version)
+    , q(_q)
+{
+}
+
 void TextInputManagerV2InterfacePrivate::zwp_text_input_manager_v2_destroy(Resource *resource)
 {
     wl_resource_destroy(resource->handle);
@@ -127,7 +132,12 @@ void TextInputManagerV2InterfacePrivate::zwp_text_input_manager_v2_get_text_inpu
     }
 
     TextInputV2InterfacePrivate *textInputPrivate = TextInputV2InterfacePrivate::get(s->textInputV2());
-    textInputPrivate->add(resource->client(), id, resource->version());
+    auto *textInputResource = textInputPrivate->add(resource->client(), id, resource->version());
+    // Send enter to this new text input object if the surface is already focused.
+    const quint32 serial = s->display()->nextSerial();
+    if (textInputPrivate->surface && textInputPrivate->surface->client()->client() == resource->client()) {
+        textInputPrivate->send_enter(textInputResource->handle, serial, textInputPrivate->surface->resource());
+    }
 }
 
 TextInputManagerV2Interface::TextInputManagerV2Interface(Display *display, QObject *parent)
@@ -141,25 +151,19 @@ TextInputManagerV2Interface::~TextInputManagerV2Interface() = default;
 void TextInputV2InterfacePrivate::sendEnter(SurfaceInterface *newSurface, quint32 serial)
 {
     EnabledEmitter emitter(q);
-    if (surface) {
-        sendLeave(serial, newSurface);
-    }
-
+    // It should be always synchronized with SeatInterface::focusedTextInputSurface.
+    Q_ASSERT(!surface && newSurface);
     surface = newSurface;
-    if (surface) {
-        const auto clientResources = textInputsForClient(newSurface->client());
-        for (auto resource : clientResources) {
-            send_enter(resource->handle, serial, newSurface->resource());
-        }
+    const auto clientResources = textInputsForClient(newSurface->client());
+    for (auto resource : clientResources) {
+        send_enter(resource->handle, serial, newSurface->resource());
     }
 }
 
 void TextInputV2InterfacePrivate::sendLeave(quint32 serial, SurfaceInterface *leavingSurface)
 {
-    if (leavingSurface != surface || !leavingSurface) {
-        return;
-    }
-
+    // It should be always synchronized with SeatInterface::focusedTextInputSurface.
+    Q_ASSERT(leavingSurface && surface == leavingSurface);
     EnabledEmitter emitter(q);
     surface.clear();
     const auto clientResources = textInputsForClient(leavingSurface->client());
@@ -180,6 +184,18 @@ void TextInputV2InterfacePrivate::preEdit(const QString &text, const QString &co
     }
 }
 
+void TextInputV2InterfacePrivate::preEditStyling(uint32_t index, uint32_t length, uint32_t style)
+{
+    if (!surface) {
+        return;
+    }
+
+    const auto clientResources = textInputsForClient(surface->client());
+    for (auto resource : clientResources) {
+        send_preedit_styling(resource->handle, index, length, style);
+    }
+}
+
 void TextInputV2InterfacePrivate::commitString(const QString &text)
 {
     if (!surface) {
@@ -191,27 +207,27 @@ void TextInputV2InterfacePrivate::commitString(const QString &text)
     }
 }
 
-void TextInputV2InterfacePrivate::keysymPressed(quint32 keysym, Qt::KeyboardModifiers modifiers)
+void TextInputV2InterfacePrivate::keysymPressed(quint32 keysym, quint32 modifiers)
 {
     if (!surface) {
         return;
     }
-    Q_UNUSED(modifiers)
+
     const QList<Resource *> textInputs = textInputsForClient(surface->client());
     for (auto resource : textInputs) {
-        send_keysym(resource->handle, seat ? seat->timestamp() : 0, keysym, WL_KEYBOARD_KEY_STATE_PRESSED, 0);
+        send_keysym(resource->handle, seat ? seat->timestamp() : 0, keysym, WL_KEYBOARD_KEY_STATE_PRESSED, modifiers);
     }
 }
 
-void TextInputV2InterfacePrivate::keysymReleased(quint32 keysym, Qt::KeyboardModifiers modifiers)
+void TextInputV2InterfacePrivate::keysymReleased(quint32 keysym, quint32 modifiers)
 {
     if (!surface) {
         return;
     }
-    Q_UNUSED(modifiers)
+
     const QList<Resource *> textInputs = textInputsForClient(surface->client());
     for (auto resource : textInputs) {
-        send_keysym(resource->handle, seat ? seat->timestamp() : 0, keysym, WL_KEYBOARD_KEY_STATE_RELEASED, 0);
+        send_keysym(resource->handle, seat ? seat->timestamp() : 0, keysym, WL_KEYBOARD_KEY_STATE_RELEASED, modifiers);
     }
 }
 
@@ -301,6 +317,17 @@ void TextInputV2InterfacePrivate::sendLanguage()
     }
 }
 
+void TextInputV2InterfacePrivate::sendModifiersMap()
+{
+    if (!surface) {
+        return;
+    }
+    const QList<Resource *> textInputs = textInputsForClient(surface->client());
+    for (auto resource : textInputs) {
+        send_modifiers_map(resource->handle, modifiersMap);
+    }
+}
+
 TextInputV2InterfacePrivate::TextInputV2InterfacePrivate(SeatInterface *seat, TextInputV2Interface *_q)
     : seat(seat)
     , q(_q)
@@ -312,7 +339,14 @@ void TextInputV2InterfacePrivate::zwp_text_input_v2_enable(Resource *resource, w
     Q_UNUSED(resource)
     EnabledEmitter emitter(q);
     auto enabledSurface = SurfaceInterface::get(s);
+    if (m_enabledSurfaces.contains(enabledSurface)) {
+        return;
+    }
     m_enabledSurfaces.insert(enabledSurface);
+    QObject::connect(enabledSurface, &SurfaceInterface::aboutToBeDestroyed, q, [this, enabledSurface] {
+        EnabledEmitter emitter(q);
+        m_enabledSurfaces.remove(enabledSurface);
+    });
 }
 
 void TextInputV2InterfacePrivate::zwp_text_input_v2_disable(Resource *resource, wl_resource *s)
@@ -320,8 +354,8 @@ void TextInputV2InterfacePrivate::zwp_text_input_v2_disable(Resource *resource,
     Q_UNUSED(resource)
     EnabledEmitter emitter(q);
     auto disabledSurface = SurfaceInterface::get(s);
+    QObject::disconnect(disabledSurface, &SurfaceInterface::aboutToBeDestroyed, q, nullptr);
     m_enabledSurfaces.remove(disabledSurface);
-
     if (disabledSurface == surface) {
         q->setInputPanelState(false, {0, 0, 0, 0});
     }
@@ -433,18 +467,22 @@ void TextInputV2Interface::preEdit(const QString &text, const QString &commit)
     d->preEdit(text, commit);
 }
 
+void TextInputV2Interface::preEditStyling(uint32_t index, uint32_t length, uint32_t style)
+{
+    d->preEditStyling(index, length, style);
+}
+
 void TextInputV2Interface::commitString(const QString &text)
 {
     d->commitString(text);
 }
 
-void TextInputV2Interface::keysymPressed(quint32 keysym, Qt::KeyboardModifiers modifiers)
+void TextInputV2Interface::keysymPressed(quint32 keysym, quint32 modifiers)
 {
-    Q_UNUSED(modifiers)
     d->keysymPressed(keysym, modifiers);
 }
 
-void TextInputV2Interface::keysymReleased(quint32 keysym, Qt::KeyboardModifiers modifiers)
+void TextInputV2Interface::keysymReleased(quint32 keysym, quint32 modifiers)
 {
     d->keysymReleased(keysym, modifiers);
 }
@@ -490,8 +528,26 @@ void TextInputV2Interface::setLanguage(const QString &languageTag)
     d->sendLanguage();
 }
 
+void TextInputV2Interface::setModifiersMap(const QByteArray &modifiersMap)
+{
+    if (d->modifiersMap == modifiersMap) {
+        // not changed
+        return;
+    }
+    d->modifiersMap = modifiersMap;
+    d->sendModifiersMap();
+}
+
 QPointer<SurfaceInterface> TextInputV2Interface::surface() const
 {
+    if (!d->surface) {
+        return nullptr;
+    }
+
+    if (!d->resourceMap().contains(d->surface->client()->client())) {
+        return nullptr;
+    }
+
     return d->surface;
 }
 
