@@ -1,10 +1,10 @@
 /*
     SPDX-FileCopyrightText: 2017 Marco Martin <notmart@gmail.com>
+    SPDX-FileCopyrightText: 2021 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef KWAYLAND_SERVER_XDGFOREIGN_INTERFACE_H
-#define KWAYLAND_SERVER_XDGFOREIGN_INTERFACE_H
+#pragma once
 
 #include <QObject>
 
@@ -12,11 +12,8 @@
 
 namespace KWaylandServer
 {
-
 class Display;
 class SurfaceInterface;
-class XdgExporterV2Interface;
-class XdgImporterV2Interface;
 class XdgForeignV2InterfacePrivate;
 
 /**
@@ -26,8 +23,6 @@ class XdgForeignV2InterfacePrivate;
  * as transient parent for one of its own surfaces.
  * This parent relationship is traced by the transientChanged signal and the
  * transientFor method.
- *
- * @since 5.40
  */
 class KWAYLANDSERVER_EXPORT XdgForeignV2Interface : public QObject
 {
@@ -57,11 +52,9 @@ Q_SIGNALS:
     void transientChanged(KWaylandServer::SurfaceInterface *child, KWaylandServer::SurfaceInterface *parent);
 
 private:
-    friend class XdgExporterV2InterfacePrivate;
-    friend class XdgImporterV2InterfacePrivate;
+    friend class XdgExporterV2Interface;
+    friend class XdgImporterV2Interface;
     QScopedPointer<XdgForeignV2InterfacePrivate> d;
 };
 
 }
-
-#endif
